==> hermes-6.0.1.52.tar.gz: hermes-6.0.1.52/lib/hermes/rex_client/tasks/sync_structures_task.rb <==
module Hermes
  module RexClient
    class SyncStructuresTask

      def sync(options = {})
        date = options[:date]
        client = options[:client] || Hermes::RexClient::Client.new
        yopmail = options[:yopmail].nil? ? true : options[:yopmail]
        dont_update_parent = options[:dont_update_parent] || false
        dont_update_lessor = options[:dont_update_lessor] || false
        dont_update_entity = options[:dont_update_entity] || false

        start = Time.now

        rex_last_updated = date || Setting.get_settings_for('rexclient').values['rex_last_updated']

        puts '-' * 100
        puts 'Structures lastModifiedDate after date'
        puts '-' * 100
        client.traverse_structures({'traceability.lastModifiedDate' => ">#{date}"},{ 
          dont_update_lessor: dont_update_lessor, 
          dont_update_entity: dont_update_entity
          }, Proc.new do |rex_entity| 
            begin
              className = (rex_entity['idEntityDefinition'] == client.ed_entity) ? 'Hermes::Entity' : 'Hermes::Lessor'
              client.log_puts "Started : Syncro #{className} id_cristal #{rex_entity['fields']['id_cristal']}"
  
              if rex_entity['fields']['id_absorbant_cristal'].blank?
                Hermes::RexClient::UpdateStructureTask.new.update_entity(rex_entity, className, client, dont_update_parent)
              end
  
              client.log_puts "Ended : Syncro #{className} id_cristal #{rex_entity['fields']['id_cristal']}"
            rescue => exception
              type = className == 'Hermes::Entity' ? 'Enity' : 'Lessor'
              client.log_puts("#{type} id_cristal: #{rex_entity['fields']['id_cristal']} => Error : #{exception}" , true)
            end

          end
        )

        puts '-' * 100
        puts 'Contacts lastModifiedDate after date'
        puts '-' * 100
        client.traverse_contacts({'traceability.lastModifiedDate' => ">#{date}"},{}, Proc.new do |rex_entity| 
            begin
              client.log_puts "Started : Syncro Contact id_cristal #{rex_entity['fields']['id_cristal']}"

              Hermes::RexClient::UpdateContactTask.new.update_contact(rex_entity, client, yopmail, false, dont_update_lessor, dont_update_entity)

              client.log_puts "Ended : Syncro Contact id_cristal #{rex_entity['fields']['id_cristal']}"
            rescue => exception
              client.log_puts("Contact id_cristal: #{rex_entity['fields']['id_cristal']} => Error : #{exception}" , true)
            end
          end
        )

        finish = Time.now

        diff = finish - start

        line = "REX sync took : #{diff} sec"
        client.save_log_and_send_email
        if client.logger
          client.logger.info line
        end 
      end
    end
  end
end

==> hermes-6.0.2.24.tar.gz: hermes-6.0.2.24/lib/hermes/rex_client/tasks/sync_structures_task.rb <==
module Hermes
  module RexClient
    class SyncStructuresTask

      def sync(options = {})
        date = options[:date]
        client = options[:client] || Hermes::RexClient::Client.new
        yopmail = options[:yopmail].nil? ? true : options[:yopmail]
        dont_update_parent = options[:dont_update_parent] || false
        dont_update_lessor = options[:dont_update_lessor] || false
        dont_update_entity = options[:dont_update_entity] || false

        start = Time.now

        rex_last_updated = date || Setting.get_settings_for('rexclient').values['rex_last_updated']

        puts '-' * 100
        puts 'Structures lastModifiedDate after date'
        puts '-' * 100
        client.traverse_structures({'traceability.lastModifiedDate' => ">#{date}"},{ 
          dont_update_lessor: dont_update_lessor, 
          dont_update_entity: dont_update_entity
          }, Proc.new do |rex_entity| 
            begin
              className = (rex_entity['idEntityDefinition'] == client.ed_entity) ? 'Hermes::Entity' : 'Hermes::Lessor'
              client.log_puts "Started : Syncro #{className} id_cristal #{rex_entity['fields']['id_cristal']}"
  
              if rex_entity['fields']['id_absorbant_cristal'].blank?
                Hermes::RexClient::UpdateStructureTask.new.update_entity(rex_entity, className, client, dont_update_parent)
              end
  
              client.log_puts "Ended : Syncro #{className} id_cristal #{rex_entity['fields']['id_cristal']}"
            rescue => exception
              type = className == 'Hermes::Entity' ? 'Entity' : 'Lessor'
              client.log_puts("#{type} id_cristal: #{rex_entity['fields']['id_cristal']} => Error : #{exception}" , true)
            end

          end
        )

        puts '-' * 100
        puts 'Contacts lastModifiedDate after date'
        puts '-' * 100
        client.traverse_contacts({'traceability.lastModifiedDate' => ">#{date}"},{}, Proc.new do |rex_entity| 
            begin
              client.log_puts "Started : Syncro Contact id_cristal #{rex_entity['fields']['id_cristal']}"

              Hermes::RexClient::UpdateContactTask.new.update_contact(rex_entity, client, yopmail, false, dont_update_lessor, dont_update_entity)

              client.log_puts "Ended : Syncro Contact id_cristal #{rex_entity['fields']['id_cristal']}"
            rescue => exception
              client.log_puts("Contact id_cristal: #{rex_entity['fields']['id_cristal']} => Error : #{exception}" , true)
            end
          end
        )

        finish = Time.now

        diff = finish - start

        line = "REX sync took : #{diff} sec"
        client.save_log_and_send_email
        if client.logger
          client.logger.info line
        end 
      end
    end
  end
end
